@@ -99,7 +99,9 @@ public class InstanceTypesServiceImpl extends ServiceImpl implements InstanceTyp
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new AddResponseImpl(XmlInstanceTypeReader.readOne(reader));
+                    AddResponseImpl actionResponse = new AddResponseImpl();
+                    actionResponse.instanceType(XmlInstanceTypeReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -110,7 +112,7 @@ public class InstanceTypesServiceImpl extends ServiceImpl implements InstanceTyp
             }
             else {
                 checkFault(response);
-                return new AddResponseImpl(null);
+                return new AddResponseImpl();
             }
         }
         
@@ -119,7 +121,7 @@ public class InstanceTypesServiceImpl extends ServiceImpl implements InstanceTyp
     private class AddResponseImpl implements AddResponse {
         private InstanceType instanceType;
         
-        public AddResponseImpl(InstanceType instanceType) {
+        public void instanceType(InstanceType instanceType) {
             this.instanceType = instanceType;
         }
         
@@ -208,7 +210,9 @@ public class InstanceTypesServiceImpl extends ServiceImpl implements InstanceTyp
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new ListResponseImpl(XmlInstanceTypeReader.readMany(reader));
+                    ListResponseImpl actionResponse = new ListResponseImpl();
+                    actionResponse.instanceType(XmlInstanceTypeReader.readMany(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -219,7 +223,7 @@ public class InstanceTypesServiceImpl extends ServiceImpl implements InstanceTyp
             }
             else {
                 checkFault(response);
-                return new ListResponseImpl(null);
+                return new ListResponseImpl();
             }
         }
         
@@ -228,7 +232,7 @@ public class InstanceTypesServiceImpl extends ServiceImpl implements InstanceTyp
     private class ListResponseImpl implements ListResponse {
         private List<InstanceType> instanceType;
         
-        public ListResponseImpl(List<InstanceType> instanceType) {
+        public void instanceType(List<InstanceType> instanceType) {
             this.instanceType = instanceType;
         }
         
