@@ -92,6 +92,10 @@ import java.util.List;
  */
 public interface HostNic extends Identified {
     BigInteger adAggregatorId();
+    Byte adAggregatorIdAsByte();
+    Short adAggregatorIdAsShort();
+    Integer adAggregatorIdAsInteger();
+    Long adAggregatorIdAsLong();
     
     boolean adAggregatorIdPresent();
     
@@ -136,6 +140,10 @@ public interface HostNic extends Identified {
     boolean macPresent();
     
     BigInteger mtu();
+    Byte mtuAsByte();
+    Short mtuAsShort();
+    Integer mtuAsInteger();
+    Long mtuAsLong();
     
     boolean mtuPresent();
     
@@ -152,6 +160,10 @@ public interface HostNic extends Identified {
     boolean propertiesPresent();
     
     BigInteger speed();
+    Byte speedAsByte();
+    Short speedAsShort();
+    Integer speedAsInteger();
+    Long speedAsLong();
     
     boolean speedPresent();
     
