@@ -20,6 +20,7 @@ import java.lang.String;
 import java.math.BigInteger;
 import java.util.List;
 import org.ovirt.engine.sdk4.types.Disk;
+import org.ovirt.engine.sdk4.types.DiskContentType;
 import org.ovirt.engine.sdk4.types.DiskFormat;
 import org.ovirt.engine.sdk4.types.DiskInterface;
 import org.ovirt.engine.sdk4.types.DiskProfile;
@@ -40,6 +41,7 @@ public class DiskContainer extends DeviceContainer implements Disk {
     private BigInteger actualSize;
     private String alias;
     private Boolean bootable;
+    private DiskContentType contentType;
     private DiskFormat format;
     private String imageId;
     private BigInteger initialSize;
@@ -139,6 +141,18 @@ public class DiskContainer extends DeviceContainer implements Disk {
         return bootable != null;
     }
     
+    public DiskContentType contentType() {
+        return contentType;
+    }
+    
+    public void contentType(DiskContentType newContentType) {
+        contentType = newContentType;
+    }
+    
+    public boolean contentTypePresent() {
+        return contentType != null;
+    }
+    
     public DiskFormat format() {
         return format;
     }
