@@ -77,7 +77,9 @@ public class AssignedCpuProfileServiceImpl extends ServiceImpl implements Assign
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new GetResponseImpl(XmlCpuProfileReader.readOne(reader));
+                    GetResponseImpl actionResponse = new GetResponseImpl();
+                    actionResponse.profile(XmlCpuProfileReader.readOne(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -88,7 +90,7 @@ public class AssignedCpuProfileServiceImpl extends ServiceImpl implements Assign
             }
             else {
                 checkFault(response);
-                return new GetResponseImpl(null);
+                return new GetResponseImpl();
             }
         }
         
@@ -97,7 +99,7 @@ public class AssignedCpuProfileServiceImpl extends ServiceImpl implements Assign
     private class GetResponseImpl implements GetResponse {
         private CpuProfile profile;
         
-        public GetResponseImpl(CpuProfile profile) {
+        public void profile(CpuProfile profile) {
             this.profile = profile;
         }
         
