@@ -98,7 +98,9 @@ public class TemplateCdromsServiceImpl extends ServiceImpl implements TemplateCd
                 try (
                   XmlReader reader = new XmlReader(response.getEntity().getContent())
                 ) {
-                    return new ListResponseImpl(XmlCdromReader.readMany(reader));
+                    ListResponseImpl actionResponse = new ListResponseImpl();
+                    actionResponse.cdroms(XmlCdromReader.readMany(reader));
+                    return actionResponse;
                 }
                 catch (IOException ex) {
                     throw new Error("Failed to read response", ex);
@@ -109,7 +111,7 @@ public class TemplateCdromsServiceImpl extends ServiceImpl implements TemplateCd
             }
             else {
                 checkFault(response);
-                return new ListResponseImpl(null);
+                return new ListResponseImpl();
             }
         }
         
@@ -118,7 +120,7 @@ public class TemplateCdromsServiceImpl extends ServiceImpl implements TemplateCd
     private class ListResponseImpl implements ListResponse {
         private List<Cdrom> cdroms;
         
-        public ListResponseImpl(List<Cdrom> cdroms) {
+        public void cdroms(List<Cdrom> cdroms) {
             this.cdroms = cdroms;
         }
         
