@@ -200,8 +200,15 @@ public interface StepsService extends Service {
      *   ...
      * </steps>
      * ----
+     * 
+     * The order of the returned list of steps isn't guaranteed.
      */
     public interface ListRequest extends Request<ListRequest, ListResponse> {
+        /**
+         * Indicates which inner links should be _followed_. The objects referenced by these links will be fetched as part
+         * of the current request. See <<documents/003_common_concepts/follow, here>> for details.
+         */
+        ListRequest follow(String follow);
         /**
          * Sets the maximum number of steps to return. If not specified all the steps are returned.
          */
@@ -245,6 +252,8 @@ public interface StepsService extends Service {
      *   ...
      * </steps>
      * ----
+     * 
+     * The order of the returned list of steps isn't guaranteed.
      */
     public interface ListResponse extends Response {
         /**
@@ -282,6 +291,8 @@ public interface StepsService extends Service {
      *   ...
      * </steps>
      * ----
+     * 
+     * The order of the returned list of steps isn't guaranteed.
      */
     ListRequest list();
     
