@@ -20,22 +20,26 @@ import java.util.List;
 import org.ovirt.engine.sdk4.Request;
 import org.ovirt.engine.sdk4.Response;
 import org.ovirt.engine.sdk4.Service;
+import org.ovirt.engine.sdk4.builders.AuthorizedKeyBuilder;
 import org.ovirt.engine.sdk4.builders.ClusterBuilder;
 import org.ovirt.engine.sdk4.builders.DiskBuilder;
 import org.ovirt.engine.sdk4.builders.HostBuilder;
 import org.ovirt.engine.sdk4.builders.SnapshotBuilder;
 import org.ovirt.engine.sdk4.builders.StorageDomainBuilder;
+import org.ovirt.engine.sdk4.builders.StorageDomainLeaseBuilder;
 import org.ovirt.engine.sdk4.builders.TicketBuilder;
 import org.ovirt.engine.sdk4.builders.VmBuilder;
+import org.ovirt.engine.sdk4.types.AuthorizedKey;
 import org.ovirt.engine.sdk4.types.Cluster;
 import org.ovirt.engine.sdk4.types.Disk;
 import org.ovirt.engine.sdk4.types.Host;
 import org.ovirt.engine.sdk4.types.Snapshot;
 import org.ovirt.engine.sdk4.types.StorageDomain;
+import org.ovirt.engine.sdk4.types.StorageDomainLease;
 import org.ovirt.engine.sdk4.types.Ticket;
 import org.ovirt.engine.sdk4.types.Vm;
 
-public interface VmService extends Service {
+public interface VmService extends MeasurableService {
     /**
      * This operation stops any migration of a virtual machine to another physical host.
      * 
@@ -198,8 +202,9 @@ public interface VmService extends Service {
     DetachRequest detach();
     
     /**
-     * Exports a virtual machine to an export domain.
+     * Exports the virtual machine.
      * 
+     * A virtual machine can be exported to an export domain.
      * For example, to export virtual machine `123` to the export domain `myexport`:
      * 
      * [source]
@@ -219,6 +224,27 @@ public interface VmService extends Service {
      *   <discard_snapshots>true</discard_snapshots>
      * </action>
      * ----
+     * 
+     * Since version 4.2 of the engine it is also possible to export a virtual machine as a virtual appliance (OVA).
+     * For example, to export virtual machine `123` as an OVA file named `myvm.ova` that is placed in the directory `/home/ovirt/` on host `myhost`:
+     * 
+     * [source]
+     * ----
+     * POST /ovirt-engine/api/vms/123/export
+     * ----
+     * 
+     * With a request body like this:
+     * 
+     * [source,xml]
+     * ----
+     * <action>
+     *   <host>
+     *     <name>myhost</name>
+     *   </host>
+     *   <directory>/home/ovirt</directory>
+     *   <filename>myvm.ova</filename>
+     * </action>
+     * ----
      */
     public interface ExportRequest extends Request<ExportRequest, ExportResponse> {
         /**
@@ -236,12 +262,16 @@ public interface VmService extends Service {
          */
         ExportRequest exclusive(Boolean exclusive);
         ExportRequest storageDomain(StorageDomain storageDomain);
+        /**
+         * The (export) storage domain to export the virtual machine to.
+         */
         ExportRequest storageDomain(StorageDomainBuilder storageDomain);
     }
     
     /**
-     * Exports a virtual machine to an export domain.
+     * Exports the virtual machine.
      * 
+     * A virtual machine can be exported to an export domain.
      * For example, to export virtual machine `123` to the export domain `myexport`:
      * 
      * [source]
@@ -261,13 +291,35 @@ public interface VmService extends Service {
      *   <discard_snapshots>true</discard_snapshots>
      * </action>
      * ----
+     * 
+     * Since version 4.2 of the engine it is also possible to export a virtual machine as a virtual appliance (OVA).
+     * For example, to export virtual machine `123` as an OVA file named `myvm.ova` that is placed in the directory `/home/ovirt/` on host `myhost`:
+     * 
+     * [source]
+     * ----
+     * POST /ovirt-engine/api/vms/123/export
+     * ----
+     * 
+     * With a request body like this:
+     * 
+     * [source,xml]
+     * ----
+     * <action>
+     *   <host>
+     *     <name>myhost</name>
+     *   </host>
+     *   <directory>/home/ovirt</directory>
+     *   <filename>myvm.ova</filename>
+     * </action>
+     * ----
      */
     public interface ExportResponse extends Response {
     }
     
     /**
-     * Exports a virtual machine to an export domain.
+     * Exports the virtual machine.
      * 
+     * A virtual machine can be exported to an export domain.
      * For example, to export virtual machine `123` to the export domain `myexport`:
      * 
      * [source]
@@ -287,6 +339,27 @@ public interface VmService extends Service {
      *   <discard_snapshots>true</discard_snapshots>
      * </action>
      * ----
+     * 
+     * Since version 4.2 of the engine it is also possible to export a virtual machine as a virtual appliance (OVA).
+     * For example, to export virtual machine `123` as an OVA file named `myvm.ova` that is placed in the directory `/home/ovirt/` on host `myhost`:
+     * 
+     * [source]
+     * ----
+     * POST /ovirt-engine/api/vms/123/export
+     * ----
+     * 
+     * With a request body like this:
+     * 
+     * [source,xml]
+     * ----
+     * <action>
+     *   <host>
+     *     <name>myhost</name>
+     *   </host>
+     *   <directory>/home/ovirt</directory>
+     *   <filename>myvm.ova</filename>
+     * </action>
+     * ----
      */
     ExportRequest export();
     
@@ -388,6 +461,11 @@ public interface VmService extends Service {
          * Indicates if the results should be filtered according to the permissions of the user.
          */
         GetRequest filter(Boolean filter);
+        /**
+         * Indicates which inner links should be _followed_. The objects referenced by these links will be fetched as part
+         * of the current request. See <<documents/003_common_concepts/follow, here>> for details.
+         */
+        GetRequest follow(String follow);
         /**
          * Indicates if the returned result describes the virtual machine as it is currently running or if describes
          * the virtual machine with the modifications that have already been performed but that will only come into
@@ -683,6 +761,17 @@ public interface VmService extends Service {
         PreviewSnapshotRequest disks(List<Disk> disks);
         PreviewSnapshotRequest disks(Disk... disks);
         PreviewSnapshotRequest disks(DiskBuilder... disks);
+        PreviewSnapshotRequest lease(StorageDomainLease lease);
+        /**
+         * Specify the lease storage domain ID to use in the preview of the snapshot.
+         * If lease parameter is not passed, then the previewed snapshot lease storage domain will be used.
+         * If lease parameter is passed with empty storage domain parameter, then no lease will be used
+         * for the snapshot preview.
+         * If lease parameter is passed with storage domain parameter then the storage domain ID can be
+         * only one of the leases domain IDs that belongs to one of the virtual machine snapshots.
+         * This is an optional parameter, set by default to `null`
+         */
+        PreviewSnapshotRequest lease(StorageDomainLeaseBuilder lease);
         PreviewSnapshotRequest restoreMemory(Boolean restoreMemory);
         PreviewSnapshotRequest snapshot(Snapshot snapshot);
         PreviewSnapshotRequest snapshot(SnapshotBuilder snapshot);
@@ -933,6 +1022,8 @@ public interface VmService extends Service {
          * Indicates if the start action should be performed asynchronously.
          */
         StartRequest async(Boolean async);
+        StartRequest authorizedKey(AuthorizedKey authorizedKey);
+        StartRequest authorizedKey(AuthorizedKeyBuilder authorizedKey);
         /**
          * Indicates if the results should be filtered according to the permissions of the user.
          */
@@ -976,6 +1067,11 @@ public interface VmService extends Service {
          * powered off, this definition will be reverted.
          */
         StartRequest vm(VmBuilder vm);
+        /**
+         * Indicates that this run configuration will be discarded even in the case of guest-initiated reboot.
+         * The default value is `false`.
+         */
+        StartRequest volatile_(Boolean volatile_);
     }
     
     /**
@@ -1371,6 +1467,94 @@ public interface VmService extends Service {
      */
     TicketRequest ticket();
     
+    /**
+     * Exports a virtual machine to an export domain.
+     */
+    public interface ExportToExportDomainRequest extends Request<ExportToExportDomainRequest, ExportToExportDomainResponse> {
+        /**
+         * Indicates if the export should be performed asynchronously.
+         */
+        ExportToExportDomainRequest async(Boolean async);
+        /**
+         * Use the `discard_snapshots` parameter when the virtual machine should be exported with all of its
+         * snapshots collapsed.
+         */
+        ExportToExportDomainRequest discardSnapshots(Boolean discardSnapshots);
+        /**
+         * Use the `exclusive` parameter when the virtual machine should be exported even if another copy of
+         * it already exists in the export domain (override).
+         */
+        ExportToExportDomainRequest exclusive(Boolean exclusive);
+        ExportToExportDomainRequest storageDomain(StorageDomain storageDomain);
+        /**
+         * The (export) storage domain to export the virtual machine to.
+         */
+        ExportToExportDomainRequest storageDomain(StorageDomainBuilder storageDomain);
+    }
+    
+    /**
+     * Exports a virtual machine to an export domain.
+     */
+    public interface ExportToExportDomainResponse extends Response {
+    }
+    
+    /**
+     * Exports a virtual machine to an export domain.
+     */
+    ExportToExportDomainRequest exportToExportDomain();
+    
+    /**
+     * Exports a virtual machine as an OVA file to a given path on a specified host.
+     */
+    public interface ExportToPathOnHostRequest extends Request<ExportToPathOnHostRequest, ExportToPathOnHostResponse> {
+        /**
+         * Indicates if the export should be performed asynchronously.
+         */
+        ExportToPathOnHostRequest async(Boolean async);
+        /**
+         * An absolute path of a directory on the host to generate the OVA file in.
+         */
+        ExportToPathOnHostRequest directory(String directory);
+        /**
+         * Use the `discard_snapshots` parameter when the virtual machine should be exported with all of its
+         * snapshots collapsed.
+         */
+        ExportToPathOnHostRequest discardSnapshots(Boolean discardSnapshots);
+        /**
+         * Use the `exclusive` parameter when the virtual machine should be exported even if another copy of
+         * it already exists in the export domain (override).
+         */
+        ExportToPathOnHostRequest exclusive(Boolean exclusive);
+        /**
+         * The name of the OVA file.
+         * 
+         * This is an optional parameter, if it is not specified then the name of OVA file is determined according
+         * to the name of the virtual machine. It will conform the following pattern: "<virtual machine name>.ova".
+         */
+        ExportToPathOnHostRequest filename(String filename);
+        ExportToPathOnHostRequest host(Host host);
+        /**
+         * The host to generate the OVA file on.
+         */
+        ExportToPathOnHostRequest host(HostBuilder host);
+        ExportToPathOnHostRequest storageDomain(StorageDomain storageDomain);
+        /**
+         * The (export) storage domain to export the virtual machine to.
+         */
+        ExportToPathOnHostRequest storageDomain(StorageDomainBuilder storageDomain);
+    }
+    
+    /**
+     * Exports a virtual machine as an OVA file to a given path on a specified host.
+     */
+    public interface ExportToPathOnHostResponse extends Response {
+    }
+    
+    /**
+     * Exports a virtual machine as an OVA file to a given path on a specified host.
+     */
+    ExportToPathOnHostRequest exportToPathOnHost();
+    
     /**
      * Restores the virtual machine to the state it had before previewing the snapshot.
      * 
@@ -1398,6 +1582,9 @@ public interface VmService extends Service {
      */
     UndoSnapshotRequest undoSnapshot();
     
+    /**
+     * Update the virtual machine in the system for the given virtual machine id.
+     */
     public interface UpdateRequest extends Request<UpdateRequest, UpdateResponse> {
         /**
          * Indicates if the update should be performed asynchronously.
@@ -1413,10 +1600,16 @@ public interface VmService extends Service {
         UpdateRequest vm(VmBuilder vm);
     }
     
+    /**
+     * Update the virtual machine in the system for the given virtual machine id.
+     */
     public interface UpdateResponse extends Response {
         Vm vm();
     }
     
+    /**
+     * Update the virtual machine in the system for the given virtual machine id.
+     */
     UpdateRequest update();
     
     /**
