@@ -96,6 +96,10 @@ public interface Action extends Identified {
     
     boolean discardSnapshotsPresent();
     
+    List<IscsiDetails> discoveredTargets();
+    
+    boolean discoveredTargetsPresent();
+    
     Disk disk();
     
     boolean diskPresent();
@@ -172,6 +176,10 @@ public interface Action extends Identified {
     
     boolean jobPresent();
     
+    StorageDomainLease lease();
+    
+    boolean leasePresent();
+    
     List<LogicalUnit> logicalUnits();
     
     boolean logicalUnitsPresent();
