@@ -16,11 +16,16 @@ limitations under the License.
 package org.ovirt.engine.sdk4.types;
 
 import java.lang.String;
+import java.math.BigInteger;
 
 /**
  * This type contains information regarding an image transfer being performed.
  */
 public interface ImageTransfer extends Identified {
+    boolean active();
+    
+    boolean activePresent();
+    
     ImageTransferDirection direction();
     
     boolean directionPresent();
@@ -37,6 +42,22 @@ public interface ImageTransfer extends Identified {
     
     boolean signedTicketPresent();
     
+    String transferUrl();
+    
+    boolean transferUrlPresent();
+    
+    BigInteger transferred();
+    Byte transferredAsByte();
+    Short transferredAsShort();
+    Integer transferredAsInteger();
+    Long transferredAsLong();
+    
+    boolean transferredPresent();
+    
+    Disk disk();
+    
+    boolean diskPresent();
+    
     Host host();
     
     boolean hostPresent();
@@ -45,4 +66,8 @@ public interface ImageTransfer extends Identified {
     
     boolean imagePresent();
     
+    DiskSnapshot snapshot();
+    
+    boolean snapshotPresent();
+    
 }
